@@ -10,7 +10,7 @@
 # 3) Install MSYS2 x64
 # 4) Open C:/msys64/clangarm64.exe
 # 5) pacman -Syu (exit then run it again)
-# 6) pacman -S mingw-w64-clang-aarch64-clang mingw-w64-clang-aarch64-openmp make git zip unzip
+# 6) pacman -S mingw-w64-clang-aarch64-clang make git zip unzip
 # 7) git clone https://github.com/kimwalisch/primesieve.git
 # 8) scripts/build_mingw64_arm64.sh
 
@@ -36,15 +36,8 @@ handle_error() {
     exit 1
 }
 
-####################################################################
-
-# The repo must no have any uncommited changes as we
-# switch to another branch during the script.
-git diff --exit-code > /dev/null || handle_error "repo must not have any uncommitted changes"
-
 # Build primesieve binary ##########################################
 
-git pull
 mkdir build-release
 cd build-release
 
@@ -52,19 +45,19 @@ clang++ -static -O3 -flto -DENABLE_MULTIARCH_ARM_SVE -DNDEBUG -D_WIN32_WINNT=0x0
 strip primesieve.exe
 
 # Create a release zip archive
-wget https://github.com/kimwalisch/primesieve/releases/download/v12.0/primesieve-12.0-win-arm64.zip
-unzip primesieve-12.0-win-arm64.zip -d primesieve-$VERSION-win-arm64
-rm primesieve-12.0-win-arm64.zip
+wget https://github.com/kimwalisch/primesieve/releases/download/v12.11/primesieve-12.11-win-arm64.zip
+unzip primesieve-12.11-win-arm64.zip -d primesieve-$VERSION-win-arm64-tmp
+rm primesieve-12.11-win-arm64.zip
 
 echo ""
 echo ""
-echo "Old file size: $(ls -l --block-size=K primesieve-$VERSION-win-arm64/primesieve.exe)"
+echo "Old file size: $(ls -l --block-size=K primesieve-$VERSION-win-arm64-tmp/primesieve.exe)"
 echo "New file size: $(ls -l --block-size=K primesieve.exe)"
 echo ""
 echo ""
 
-mv -f primesieve.exe primesieve-$VERSION-win-arm64
-cd primesieve-$VERSION-win-arm64
+mv -f primesieve.exe primesieve-$VERSION-win-arm64-tmp
+cd primesieve-$VERSION-win-arm64-tmp
 sed -i "1 s/.*/primesieve $VERSION/" README.txt
 sed -i "2 s/.*/$FULL_DATE/" README.txt
 sed -i "3 s/.*/Copyright \(c\) 2010 - $YEAR, Kim Walisch\./" COPYING
@@ -74,9 +67,6 @@ sed -i "3 s/.*/Copyright \(c\) 2010 - $YEAR, Kim Walisch\./" COPYING
 [ "$(sed -n '2p' < README.txt)" = "$FULL_DATE" ] || handle_error "failed updating README.txt"
 [ "$(sed -n '3p' < COPYING)" = "Copyright (c) 2010 - $YEAR, Kim Walisch." ] || handle_error "failed updating COPYING"
 
-zip primesieve-$VERSION-win-arm64.zip primesieve.exe README.txt COPYING
-cp primesieve-$VERSION-win-arm64.zip ..
-
 ./primesieve -v
 echo ""
 echo ""
@@ -93,6 +83,13 @@ echo ""
 echo ""
 echo ""
 
+# Build release zip archive ########################################
+
+zip primesieve-$VERSION-win-arm64.zip primesieve.exe README.txt COPYING
+mv primesieve-$VERSION-win-arm64.zip ..
+cd ..
+mv primesieve-$VERSION-win-arm64-tmp primesieve-$VERSION-win-arm64
+
 ####################################################################
 
 echo "Release binary built successfully!"
