@@ -33,35 +33,28 @@ handle_error() {
     exit 1
 }
 
-####################################################################
-
-# The repo must no have any uncommited changes as we
-# switch to another branch during the script.
-git diff --exit-code > /dev/null || handle_error "repo must not have any uncommitted changes"
-
 # Build primesieve binary ##########################################
 
-git pull
 mkdir build-release
 cd build-release
 
-g++ -static -O3 -mpopcnt -flto -DNDEBUG -D_WIN32_WINNT=0x0A00 -Wall -Wextra -pedantic -DENABLE_MULTIARCH_AVX512_BW -DENABLE_MULTIARCH_AVX512_VBMI2 -I ../include ../src/*.cpp ../src/x86/*.cpp ../src/app/*.cpp -o primesieve.exe
+g++ -static -O3 -mpopcnt -flto -DNDEBUG -D_WIN32_WINNT=0x0A00 -Wall -Wextra -pedantic -DENABLE_MULTIARCH_AVX512_BW -DENABLE_MULTIARCH_AVX512_VBMI2 -I../include -I../src ../src/*.cpp ../src/arch/x86/*.cpp ../src/app/*.cpp -o primesieve.exe
 strip primesieve.exe
 
 # Create a release zip archive
-wget https://github.com/kimwalisch/primesieve/releases/download/v12.0/primesieve-12.0-win-x64.zip
-unzip primesieve-12.0-win-x64.zip -d primesieve-$VERSION-win-x64
-rm primesieve-12.0-win-x64.zip
+wget https://github.com/kimwalisch/primesieve/releases/download/v12.11/primesieve-12.11-win-x64.zip
+unzip primesieve-12.11-win-x64.zip -d primesieve-$VERSION-win-x64-tmp
+rm primesieve-12.11-win-x64.zip
 
 echo ""
 echo ""
-echo "Old file size: $(ls -l --block-size=K primesieve-$VERSION-win-x64/primesieve.exe)"
+echo "Old file size: $(ls -l --block-size=K primesieve-$VERSION-win-x64-tmp/primesieve.exe)"
 echo "New file size: $(ls -l --block-size=K primesieve.exe)"
 echo ""
 echo ""
 
-mv -f primesieve.exe primesieve-$VERSION-win-x64
-cd primesieve-$VERSION-win-x64
+mv -f primesieve.exe primesieve-$VERSION-win-x64-tmp
+cd primesieve-$VERSION-win-x64-tmp
 sed -i "1 s/.*/primesieve $VERSION/" README.txt
 sed -i "2 s/.*/$FULL_DATE/" README.txt
 sed -i "3 s/.*/Copyright \(c\) 2010 - $YEAR, Kim Walisch\./" COPYING
@@ -71,9 +64,6 @@ sed -i "3 s/.*/Copyright \(c\) 2010 - $YEAR, Kim Walisch\./" COPYING
 [ "$(sed -n '2p' < README.txt)" = "$FULL_DATE" ] || handle_error "failed updating README.txt"
 [ "$(sed -n '3p' < COPYING)" = "Copyright (c) 2010 - $YEAR, Kim Walisch." ] || handle_error "failed updating COPYING"
 
-zip primesieve-$VERSION-win-x64.zip primesieve.exe README.txt COPYING
-cp primesieve-$VERSION-win-x64.zip ..
-
 ./primesieve -v
 echo ""
 echo ""
@@ -90,6 +80,13 @@ echo ""
 echo ""
 echo ""
 
+# Build release zip archive ########################################
+
+zip primesieve-$VERSION-win-x64.zip primesieve.exe README.txt COPYING
+mv primesieve-$VERSION-win-x64.zip ..
+cd ..
+mv primesieve-$VERSION-win-x64-tmp primesieve-$VERSION-win-x64
+
 ####################################################################
 
 echo "Release binary built successfully!"
